Module output

Module output 

Components for constructing HTTP responses.

Re-exports

pub use self::fs::NamedFile;

Modules

body
The definition of ResBody and implementors of Payload.
fs
status

Structs

Debug
An instance of Output representing text responses with debug output.
Json
An instance of Output representing statically typed JSON responses.
OutputContext
Contextual information at applying Output::respond.
Pretty
A wrapper type to use pretty output for the internal value.
Redirect
An instance of Output representing redirect responses.

Traits

Output
A trait representing the value to be converted into an HTTP response.