Components for constructing HTTP responses.
Re-exports
pub use self::fs::NamedFile;
Modules
Structs
- Debug
- An instance of
Outputrepresenting text responses with debug output. - Json
- An instance of
Outputrepresenting statically typed JSON responses. - Output
Context - Contextual information at applying
Output::respond. - Pretty
- A wrapper type to use pretty output for the internal value.
- Redirect
- An instance of
Outputrepresenting redirect responses.
Traits
- Output
- A trait representing the value to be converted into an HTTP response.